function [magnfac]=elflux2(ex,ey,es,magnfac)
[nargout,nargin] = argn(0);

// Display warning for floating point exception
ieee(1)
//elflux2(ex,ey,es,magnfac)
//[magnfac]=elflux2(ex,ey,es)
//-------------------------------------------------------------
// PURPOSE 
//   Display element flow arrows for a number of 2D scalar elements of 
//   the same type. To display elements and nodes, use eldraw2. 
//   Supported elements are:
//
//     1) -> triangular 3 node el.    2) -> quadrilateral 4 node el. 
//
// INPUT    
//    ex,ey:.......... nen:   number of element nodes
//                     nel:   number of elements   
//    es:     element flow matrix
//
//        
//    magnfac: magnification factor  =  arrowlength / element flow
//
//    Remark: If magnfac and plotpar is left out the default is 
//            auto magnification and solid white arrows.
//         
//-------------------------------------------------------------

// LAST MODIFIED: J Lindemann 1999-01-29 
// Copyright (c)  Division of Structural Mechanics and
//                Department of Solid Mechanics.
//                Lund Institute of Technology
//-------------------------------------------------------------
//
 if ~((nargin==3)|(nargin==4))
    disp('??? Wrong number of input arguments!')
    return
 end
 
 a=size(ex); b=size(ey); c=size(es);
 
 if (a-b)==[0 0]
     nel=a(1);nen=a(2); 
 else
    disp('??? Check size of coordinate input arguments!') 
    return
 end

 if ~(c(1)==a(1))
    disp('??? Check size of flow input argument!')
    disp('One row for each element, i.e the mean flow in x- and y-directions !') 
    return
 end
 
 ned=c(2); 
 
// if ned~=nen ; 
//    disp('??? This function should be used for scalar problems!')
// end

 dxmax=max(max(ex')-min(ex')); 
 dymax=max(max(ey')-min(ey'));
 lm=sum(sqrt(dxmax.^2+dymax.^2))/nel;
 
 qm=sum(sqrt(sum((es').^2)))/nel;

 krel=0.8;
 
 if nargin==3; 
    magnfac=lm*krel/qm;
 end
// *****************************************************************
 if ~((nen==3)|(nen==4))  
     disp('Sorry, this element is currently not supported!') 
     return
 else
// ************* plot commands ******************* 
 
    q=sqrt(sum((es').^2,1));
    la=magnfac*q; fi=atan(es(:,2),es(:,1));
    [g1,g2]=size(la)
    loc=zeros(g1,g2);
  
    x0=sum(ex',1)/nen; y0=sum(ey',1)/nen;
 
    xyl0=[-0.5 0.35 0.35 0.5 0.35 0.35;
         0   0  -0.05  0  0.05  0  ];
    nar=length(x0);

    for i=1:nar
      xyl=xyl0-0.5*loc(i)*[1 1 1 1 1 1;
                           0 0 0 0 0 0];
      v=fi(i); L=la(i);
      xy=L*[ cos(v)  -sin(v) ;
             sin(v)   cos(v) ]*xyl+[x0(i)*ones(1,6);
                                    y0(i)*ones(1,6)];
      plot2d( xy(1,:)',xy(2,:)')
    end;
  end
endfunction
